@@ -23,7 +23,6 @@ use List::MoreUtils 0.423;
 use PDL::Primitive ();
 use PDL::Factor    ();
 use PDL::SV        ();
-use PDL::Stats::Basic ();
 use PDL::StringfiableExtension;
 use Ref::Util qw(is_plain_arrayref is_plain_hashref);
 use Scalar::Util qw(blessed looks_like_number);
@@ -510,6 +509,12 @@ method summary ($percentiles=[0.25, 0.75]) {
         die "percentiles should all be in the interval [0, 1].";
     }
 
+    state $std = sub {
+        my ($p) = @_;
+        $p = $p->where( $p->isgood );
+        return sqrt( ( ( ( $p - $p->average )**2 )->sum ) / $p->length );
+    };
+
     my $class = ref($self);
     my @pct   = sort { $a <=> $b }
       List::AllUtils::uniq( ( ( $percentiles->flatten ), 0.5 ) );
@@ -530,7 +535,7 @@ method summary ($percentiles=[0.25, 0.75]) {
             else {
                 $_ => pdl(
                     [
-                        $count, $average,  $col->stdv_unbiased,
+                        $count, $average,  $std->($col),
                         $min,   @pct_data, $max
                     ]
                 );
@@ -645,10 +650,10 @@ method which (:$bad_to_val=undef, :$ignore_both_bad=true) {
     my $coordinates = [ 0 .. $self->ncol - 1 ]->map(
         fun($cidx)
         {
-            my $column = $self->at( indexer_i( [$cidx] ) );
+            my $column = $self->nth_column( $cidx );
             my $both_bad =
                 $self->DOES('Data::Frame::Role::CompareResult')
-              ? $self->both_bad->at( indexer_i( [$cidx] ) )
+              ? $self->both_bad->nth_column( $cidx )
               : undef;
 
             if ( defined $bad_to_val ) {
@@ -667,8 +672,8 @@ method which (:$bad_to_val=undef, :$ignore_both_bad=true) {
 method merge (DataFrame $df) {
     my $class   = ref($self);
     my $columns = [
-        $self->names->map( sub { $_ => $self->at($_) } )->flatten,
-        $df->names->map( sub { $_ => $df->at($_) } )->flatten
+        $self->names->map( sub { $_ => $self->column($_) } )->flatten,
+        $df->names->map( sub { $_ => $df->column($_) } )->flatten
     ];
     return $class->new(
         columns   => $columns,
@@ -688,9 +693,9 @@ method append (DataFrame $df) {
     my $class   = ref($self);
     my $columns = $self->names->map(
         sub {
-            my $col = $self->at($_);
+            my $col = $self->column($_);
             # use glue() as PDL's append() cannot handle bad values
-            $_ => $col->glue( 0, $df->at($_) );
+            $_ => $col->glue( 0, $df->column($_) );
         }
     );
     return $class->new( columns => $columns );
@@ -714,7 +719,7 @@ method transform ($func) {
     if ( Ref::Util::is_coderef($func) ) {
         @columns =
           $self->names->map( sub {
-            $_ => $func->( $self->at($_), $self );
+            $_ => $func->( $self->column($_), $self );
           } )->flatten;
     }
     else {    # hashref or arrayref
@@ -735,7 +740,7 @@ method transform ($func) {
             sub {
                 my $f = exists($hashref->{$_}) ? $hashref->{$_} : sub { $_[0] };
                 $f //= sub { undef };
-                $_ => $f->( $self->at($_), $self );
+                $_ => $f->( $self->column($_), $self );
             }
         )->flatten;
         push @columns,
@@ -816,7 +821,7 @@ method sorti ($by_columns, $ascending=true) {
 
 method _serialize_row ($i) {
     state $sereal = Sereal::Encoder->new();
-    my @row_data = map { $self->at($_)->at($i) } @{ $self->column_names };
+    my @row_data = map { $self->column($_)->at($i) } @{ $self->column_names };
     return $sereal->encode( \@row_data );
 }
 
@@ -867,8 +872,8 @@ method assign ((DataFrame | Piddle) $x) {
             die "Cannot assign a data frame of different shape.";
         }
         for my $name ( $self->names->flatten ) {
-            my $col = $self->at($name);
-            $col .= $x->at($name);
+            my $col = $self->column($name);
+            $col .= $x->column($name);
         }
     }
     elsif ( $x->$_DOES('PDL') ) {
@@ -962,7 +967,7 @@ method _compare ($other, $mode) {
     my $compare_column = sub {
         my ( $name, $x ) = @_;
 
-        my $col = $self->at($name);
+        my $col = $self->column($name);
 
         my $fcompare;
         if ( $self->is_numeric_column($name) ) {
@@ -999,7 +1004,7 @@ method _compare ($other, $mode) {
         }
         $result_columns = {
             $self->names->map(
-                sub { $_ => [ $compare_column->( $_, $other->at($_) ) ]; }
+                sub { $_ => [ $compare_column->( $_, $other->column($_) ) ]; }
             )->flatten
         };
     }
@@ -1046,7 +1051,7 @@ Data::Frame - data frame implementation
 
 =head1 VERSION
 
-version 0.0043
+version 0.0045
 
 =head1 STATUS
 
